@@ -41,6 +41,11 @@ class CreateLindormInstanceRequest(RpcRequest):
 
 	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
 		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_AutoRenewDuration(self): # String
+		return self.get_query_params().get('AutoRenewDuration')
+
+	def set_AutoRenewDuration(self, AutoRenewDuration):  # String
+		self.add_query_param('AutoRenewDuration', AutoRenewDuration)
 	def get_ResourceGroupId(self): # String
 		return self.get_query_params().get('ResourceGroupId')
 
@@ -51,6 +56,11 @@ class CreateLindormInstanceRequest(RpcRequest):
 
 	def set_LogSpec(self, LogSpec):  # String
 		self.add_query_param('LogSpec', LogSpec)
+	def get_AutoRenewal(self): # Boolean
+		return self.get_query_params().get('AutoRenewal')
+
+	def set_AutoRenewal(self, AutoRenewal):  # Boolean
+		self.add_query_param('AutoRenewal', AutoRenewal)
 	def get_SecurityToken(self): # String
 		return self.get_query_params().get('SecurityToken')
 
@@ -61,6 +71,11 @@ class CreateLindormInstanceRequest(RpcRequest):
 
 	def set_TsdbNum(self, TsdbNum):  # Integer
 		self.add_query_param('TsdbNum', TsdbNum)
+	def get_PrimaryVSwitchId(self): # String
+		return self.get_query_params().get('PrimaryVSwitchId')
+
+	def set_PrimaryVSwitchId(self, PrimaryVSwitchId):  # String
+		self.add_query_param('PrimaryVSwitchId', PrimaryVSwitchId)
 	def get_SolrNum(self): # Integer
 		return self.get_query_params().get('SolrNum')
 
@@ -86,6 +101,11 @@ class CreateLindormInstanceRequest(RpcRequest):
 
 	def set_VSwitchId(self, VSwitchId):  # String
 		self.add_query_param('VSwitchId', VSwitchId)
+	def get_StreamNum(self): # Integer
+		return self.get_query_params().get('StreamNum')
+
+	def set_StreamNum(self, StreamNum):  # Integer
+		self.add_query_param('StreamNum', StreamNum)
 	def get_LogSingleStorage(self): # Integer
 		return self.get_query_params().get('LogSingleStorage')
 
@@ -116,6 +136,11 @@ class CreateLindormInstanceRequest(RpcRequest):
 
 	def set_TsdbSpec(self, TsdbSpec):  # String
 		self.add_query_param('TsdbSpec', TsdbSpec)
+	def get_PrimaryZoneId(self): # String
+		return self.get_query_params().get('PrimaryZoneId')
+
+	def set_PrimaryZoneId(self, PrimaryZoneId):  # String
+		self.add_query_param('PrimaryZoneId', PrimaryZoneId)
 	def get_FilestoreSpec(self): # String
 		return self.get_query_params().get('FilestoreSpec')
 
@@ -191,6 +216,11 @@ class CreateLindormInstanceRequest(RpcRequest):
 
 	def set_FilestoreNum(self, FilestoreNum):  # Integer
 		self.add_query_param('FilestoreNum', FilestoreNum)
+	def get_StreamSpec(self): # String
+		return self.get_query_params().get('StreamSpec')
+
+	def set_StreamSpec(self, StreamSpec):  # String
+		self.add_query_param('StreamSpec', StreamSpec)
 	def get_CoreSpec(self): # String
 		return self.get_query_params().get('CoreSpec')
 
